Struct DataCallBuilder
pub struct DataCallBuilder {
profile: u8,
reconnect: bool,
ip_family: IpFamily,
}Expand description
See: DataCall::builder.
Fields
profile: u8reconnect: boolip_family: IpFamilyImplementations
impl DataCallBuilder
impl DataCallBuilder
const fn new_priv() -> Self
pub const fn new() -> Self
👎Deprecated since 1.1.0: Use
DataCall::builder() insteadpub const fn profile(&mut self, profile: u8) -> &mut Self
pub const fn profile(&mut self, profile: u8) -> &mut Self
Sets the APN profile to be used for this data call.
Defaults to 0.
pub const fn profile_idx(&mut self, profile_idx: u8) -> &mut Self
👎Deprecated since 1.1.0: Use
profile insteadpub const fn reconnect(&mut self, reconnect: bool) -> &mut Self
pub const fn reconnect(&mut self, reconnect: bool) -> &mut Self
Sets whether to re-dial after disconnecting the network.
Defaults to false.
pub const fn ip_family(&mut self, ip_family: IpFamily) -> &mut Self
pub const fn ip_family(&mut self, ip_family: IpFamily) -> &mut Self
Sets the IP family for this data call.
Defaults to IpFamily::IPV4.
pub const fn build_into(&self, data_call: &mut DataCall)
pub const fn build_into(&self, data_call: &mut DataCall)
Builds a data call, writing to an existing DataCall struct.